==> estateplat-common-1.2.1-20170516.083041-19-sources.jar: cn/gtmap/estateplat/model/resources/core/ZrzySlld.java <==
package cn.gtmap.estateplat.model.resources.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2017-4-18
 * @description 自然资源森林表
 */
@Table(name = "zrzy_slld")
public class ZrzySlld extends ZrzyParent implements ZrzyVo, InsertVo {
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 自然资源ID
     */
    @Id
    private String zrzyid;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 登记项目ID
     */
    private String proid;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 自然资源编号
     */
    private String zrzybh;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 名称
     */
    private String mc;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 自然资源单元号
     */
    private String zrzydyh;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 株数
     */
    private Integer zs;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 面积
     */
    private Double mj;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 面积单位
     */
    private String mjdw;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 林种
     */
    private String lz;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 起源
     */
    private String qy;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 造林年度
     */
    private Integer zlnd;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 林班
     */
    private String lb;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 小班
     */
    private String xb;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 小地名
     */
    private String xdm;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 区县代码
     */
    private String qxdm;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 调查人
     */
    private String dcr;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 调查时间
     */
    private Date dcsj;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 备注
     */
    private String bz;

    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 权属状态
     */
    private String qszt;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 质量
     */
    private String zhl;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 数量
     */

    private Double sl;

    public String getZrzyid() {
        return zrzyid;
    }

    public void setZrzyid(String zrzyid) {
        this.zrzyid = zrzyid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getZrzybh() {
        return zrzybh;
    }

    public void setZrzybh(String zrzybh) {
        this.zrzybh = zrzybh;
    }

    public String getMc() {
        return mc;
    }

    public void setMc(String mc) {
        this.mc = mc;
    }

    public String getZrzydyh() {
        return zrzydyh;
    }

    public void setZrzydyh(String zrzydyh) {
        this.zrzydyh = zrzydyh;
    }

    public Integer getZs() {
        return zs;
    }

    public void setZs(Integer zs) {
        this.zs = zs;
    }

    public Double getMj() {
        return mj;
    }

    public void setMj(Double mj) {
        this.mj = mj;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getLz() {
        return lz;
    }

    public void setLz(String lz) {
        this.lz = lz;
    }

    public String getQy() {
        return qy;
    }

    public void setQy(String qy) {
        this.qy = qy;
    }

    public Integer getZlnd() {
        return zlnd;
    }

    public void setZlnd(Integer zlnd) {
        this.zlnd = zlnd;
    }

    public String getLb() {
        return lb;
    }

    public void setLb(String lb) {
        this.lb = lb;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getXdm() {
        return xdm;
    }

    public void setXdm(String xdm) {
        this.xdm = xdm;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getDcr() {
        return dcr;
    }

    public void setDcr(String dcr) {
        this.dcr = dcr;
    }

    public Date getDcsj() {
        return dcsj;
    }

    public void setDcsj(Date dcsj) {
        this.dcsj = dcsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getZhl() {
        return zhl;
    }

    public void setZhl(String zhl) {
        this.zhl = zhl;
    }

    public Double getSl() {
        return sl;
    }

    public void setSl(Double sl) {
        this.sl = sl;
    }
}

==> estateplat-common-1.2.3-20180612.130104-116-sources.jar: cn/gtmap/estateplat/model/resources/core/ZrzySlld.java <==
package cn.gtmap.estateplat.model.resources.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2017-4-18
 * @description 自然资源森林表
 */
@Table(name = "zrzy_slld")
public class ZrzySlld extends ZrzyParent implements ZrzyVo, InsertVo {
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 自然资源ID
     */
    @Id
    private String zrzyid;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 登记项目ID
     */
    private String proid;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 自然资源编号
     */
    private String zrzybh;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 名称
     */
    private String mc;

    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 主要树种
     */
    private String zysz;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 自然资源单元号
     */
    private String zrzydyh;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 株数
     */
    private Integer zs;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 面积
     */
    private Double mj;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 面积单位
     */
    private String mjdw;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 林种
     */
    private String lz;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 起源
     */
    private String qy;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 造林年度
     */
    private Integer zlnd;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 林班
     */
    private String lb;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 小班
     */
    private String xb;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 小地名
     */
    private String xdm;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 区县代码
     */
    private String qxdm;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 调查人
     */
    private String dcr;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 调查时间
     */
    private Date dcsj;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 备注
     */
    private String bz;

    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 权属状态
     */
    private String qszt;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 质量
     */
    private String zhl;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 数量
     */

    private Double sl;

    public String getZrzyid() {
        return zrzyid;
    }

    public void setZrzyid(String zrzyid) {
        this.zrzyid = zrzyid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getZrzybh() {
        return zrzybh;
    }

    public void setZrzybh(String zrzybh) {
        this.zrzybh = zrzybh;
    }

    public String getMc() {
        return mc;
    }

    public void setMc(String mc) {
        this.mc = mc;
    }

    public String getZysz() {
        return zysz;
    }

    public void setZysz(String zysz) {
        this.zysz = zysz;
    }

    public String getZrzydyh() {
        return zrzydyh;
    }

    public void setZrzydyh(String zrzydyh) {
        this.zrzydyh = zrzydyh;
    }

    public Integer getZs() {
        return zs;
    }

    public void setZs(Integer zs) {
        this.zs = zs;
    }

    public Double getMj() {
        return mj;
    }

    public void setMj(Double mj) {
        this.mj = mj;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getLz() {
        return lz;
    }

    public void setLz(String lz) {
        this.lz = lz;
    }

    public String getQy() {
        return qy;
    }

    public void setQy(String qy) {
        this.qy = qy;
    }

    public Integer getZlnd() {
        return zlnd;
    }

    public void setZlnd(Integer zlnd) {
        this.zlnd = zlnd;
    }

    public String getLb() {
        return lb;
    }

    public void setLb(String lb) {
        this.lb = lb;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getXdm() {
        return xdm;
    }

    public void setXdm(String xdm) {
        this.xdm = xdm;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getDcr() {
        return dcr;
    }

    public void setDcr(String dcr) {
        this.dcr = dcr;
    }

    public Date getDcsj() {
        return dcsj;
    }

    public void setDcsj(Date dcsj) {
        this.dcsj = dcsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getZhl() {
        return zhl;
    }

    public void setZhl(String zhl) {
        this.zhl = zhl;
    }

    public Double getSl() {
        return sl;
    }

    public void setSl(Double sl) {
        this.sl = sl;
    }
}
